@@ -25,6 +25,10 @@ class DatabaseCreation(PostgresDatabaseCreation):
             # greatest(): expected avg(price) to be of type float, found type
             # decimal: https://github.com/cockroachdb/django-cockroachdb/issues/74
             'aggregation.tests.AggregateTestCase.test_expression_on_aggregation',
+            # stddev/variance functions not supported:
+            # https://github.com/cockroachdb/django-cockroachdb/issues/25
+            'aggregation.test_filter_argument.FilteredAggregateTests.test_filtered_numerical_aggregates',
+            'aggregation_regress.tests.AggregationTests.test_stddev',
             # POWER() doesn't support negative exponents:
             # https://github.com/cockroachdb/django-cockroachdb/issues/22
             'db_functions.math.test_power.PowerTests.test_integer',
@@ -44,6 +48,7 @@ class DatabaseCreation(PostgresDatabaseCreation):
             'queries.test_bulk_update.BulkUpdateNoteTests.test_multiple_fields',
             'queries.test_bulk_update.BulkUpdateTests.test_inherited_fields',
             'queries.tests.Queries1Tests.test_ticket9411',
+            'queries.tests.Ticket14056Tests.test_ticket_14056',
             'queries.tests.RelatedLookupTypeTests.test_values_queryset_lookup',
             'syndication_tests.tests.SyndicationFeedTest.test_rss2_feed',
             'syndication_tests.tests.SyndicationFeedTest.test_latest_post_date',
@@ -51,24 +56,37 @@ class DatabaseCreation(PostgresDatabaseCreation):
             'syndication_tests.tests.SyndicationFeedTest.test_template_feed',
             # Transaction issues: https://github.com/cockroachdb/django-cockroachdb/issues/14
             'delete_regress.tests.DeleteLockingTest.test_concurrent_delete',
+            # unknown function: sha224() and sha384():
+            # https://github.com/cockroachdb/django-cockroachdb/issues/81
+            'db_functions.text.test_sha224.SHA224Tests.test_basic',
+            'db_functions.text.test_sha224.SHA224Tests.test_transform',
+            'db_functions.text.test_sha384.SHA384Tests.test_basic',
+            'db_functions.text.test_sha384.SHA384Tests.test_transform',
             # Unsupported query: mixed type addition in SELECT:
             # https://github.com/cockroachdb/django-cockroachdb/issues/19
             'annotations.tests.NonAggregateAnnotationTestCase.test_mixed_type_annotation_numbers',
+            # Nondeterministic query: https://github.com/cockroachdb/django-cockroachdb/issues/48
+            'queries.tests.SubqueryTests.test_slice_subquery_and_query',
             # Forward references in fixtures won't work until cockroachdb can
             # disable constraints: https://github.com/cockroachdb/cockroach/issues/19444
             'serializers.test_data.SerializerDataTests.test_json_serializer',
             'serializers.test_data.SerializerDataTests.test_python_serializer',
             'serializers.test_data.SerializerDataTests.test_xml_serializer',
             'serializers.test_data.SerializerDataTests.test_yaml_serializer',
+            # cockroachdb doesn't distinguish between tables and views. Both
+            # are included regardless of whether inspectdb's --include-views
+            # option is set.
+            'inspectdb.tests.InspectDBTransactionalTests.test_include_views',
+            'introspection.tests.IntrospectionTests.test_table_names_with_views',
             # No sequence for AutoField in cockroachdb.
             'introspection.tests.IntrospectionTests.test_sequence_list',
+            # CharField max_length is ignored on cockroachdb. CharField is
+            # introspected as TextField.
+            'introspection.tests.IntrospectionTests.test_get_table_description_col_lengths',
             # Unsupported query: unsupported binary operator: <int> / <int>:
             # https://github.com/cockroachdb/django-cockroachdb/issues/21
             'expressions.tests.ExpressionOperatorTests.test_lefthand_division',
             'expressions.tests.ExpressionOperatorTests.test_right_hand_division',
-            # Skipped for PostgreSQL but should be skipped for cockroachdb also:
-            # https://github.com/cockroachdb/django-cockroachdb/issues/57
-            'expressions_window.tests.WindowFunctionTests.test_range_n_preceding_and_following',
             # cockroachdb doesn't support disabling constraints:
             # https://github.com/cockroachdb/cockroach/issues/19444
             'auth_tests.test_views.UUIDUserTests.test_admin_password_change',
@@ -89,10 +107,13 @@ class DatabaseCreation(PostgresDatabaseCreation):
             'migrations.test_executor.ExecutorTests.test_alter_id_type_with_fk',
             'migrations.test_operations.OperationTests.test_alter_field_pk_fk',
             'migrations.test_operations.OperationTests.test_alter_field_reloads_state_on_fk_target_changes',
+            'migrations.test_operations.OperationTests.test_alter_field_reloads_state_on_fk_with_to_field_related_name_target_type_change',  # noqa
             'migrations.test_operations.OperationTests.test_alter_field_reloads_state_on_fk_with_to_field_target_changes',  # noqa
+            'migrations.test_operations.OperationTests.test_alter_field_reloads_state_on_fk_with_to_field_target_type_change',  # noqa
             'migrations.test_operations.OperationTests.test_alter_fk_non_fk',
             'migrations.test_operations.OperationTests.test_rename_field_reloads_state_on_fk_target_changes',
             'schema.tests.SchemaTests.test_alter_auto_field_to_char_field',
+            'schema.tests.SchemaTests.test_alter_autofield_pk_to_smallautofield_pk_sequence_owner',
             'schema.tests.SchemaTests.test_alter_text_field_to_date_field',
             'schema.tests.SchemaTests.test_alter_text_field_to_datetime_field',
             'schema.tests.SchemaTests.test_alter_text_field_to_time_field',
@@ -106,15 +127,25 @@ class DatabaseCreation(PostgresDatabaseCreation):
             # cockroachdb doesn't support changing the primary key of table.
             'schema.tests.SchemaTests.test_alter_not_unique_field_to_primary_key',
             'schema.tests.SchemaTests.test_primary_key',
+            # SmallAutoField doesn't work:
+            # https://github.com/cockroachdb/cockroach-django/issues/84
+            'many_to_one.tests.ManyToOneTests.test_fk_to_smallautofield',
+            'migrations.test_operations.OperationTests.test_smallfield_autofield_foreignfield_growth',
+            'migrations.test_operations.OperationTests.test_smallfield_bigautofield_foreignfield_growth',
             # This backend raises "ValueError: CockroachDB's EXPLAIN doesn't
             # support any formats." instead of an "unknown format" error.
             'queries.test_explain.ExplainTests.test_unknown_format',
+            # timezones after 2038 use incorrect DST settings:
+            # https://github.com/cockroachdb/django-cockroachdb/issues/124
+            'expressions.tests.FTimeDeltaTests.test_datetime_subtraction_microseconds',
         )
         if self.connection.features.is_cockroachdb_20_1:
             expected_failures += (
-                # timezones after 2038 use incorrect DST settings:
-                # https://github.com/cockroachdb/django-cockroachdb/issues/124
-                'expressions.tests.FTimeDeltaTests.test_datetime_subtraction_microseconds',
+                # InternalError: unexpected error: received 4 results, limit
+                # was 3 (original limit: 3, batch=1 Scan idx=0):
+                # https://github.com/cockroachdb/cockroach/issues/46652
+                'admin_filters.tests.ListFiltersTests.test_simplelistfilter_with_queryset_based_lookups',
+                'expressions_case.tests.CaseExpressionTests.test_update_fk',
             )
         if not self.connection.features.is_cockroachdb_20_1:
             expected_failures += (
@@ -165,6 +196,7 @@ class DatabaseCreation(PostgresDatabaseCreation):
                 'db_functions.datetime.test_extract_trunc.DateFunctionWithTimeZoneTests.test_trunc_minute_func',
                 'db_functions.datetime.test_extract_trunc.DateFunctionWithTimeZoneTests.test_trunc_second_func',
                 'db_functions.datetime.test_extract_trunc.DateFunctionWithTimeZoneTests.test_trunc_timezone_applied_before_truncation',  # noqa
+                'db_functions.datetime.test_extract_trunc.DateFunctionWithTimeZoneTests.test_trunc_ambiguous_and_invalid_times',  # noqa
                 'extra_regress.tests.ExtraRegressTests.test_dates_query',
                 'many_to_one.tests.ManyToOneTests.test_select_related',
                 'model_inheritance_regress.tests.ModelInheritanceTest.test_issue_7105',
@@ -232,23 +264,6 @@ class DatabaseCreation(PostgresDatabaseCreation):
                 'transaction_hooks.tests.TestConnectionOnCommit.test_discards_hooks_from_rolled_back_savepoint',
                 'transaction_hooks.tests.TestConnectionOnCommit.test_inner_savepoint_rolled_back_with_outer',
                 'transaction_hooks.tests.TestConnectionOnCommit.test_inner_savepoint_does_not_affect_outer',
-                # CharField max_length is ignored on cockroachdb. CharField is
-                # introspected as TextField.
-                'introspection.tests.IntrospectionTests.test_get_table_description_col_lengths',
-            )
-        if not self.connection.features.is_cockroachdb_20_2:
-            expected_failures += (
-                # stddev/variance functions not supported:
-                # https://github.com/cockroachdb/django-cockroachdb/issues/25
-                'aggregation.test_filter_argument.FilteredAggregateTests.test_filtered_numerical_aggregates',
-                'aggregation_regress.tests.AggregationTests.test_stddev',
-                # Nondeterministic query: https://github.com/cockroachdb/django-cockroachdb/issues/48
-                'queries.tests.SubqueryTests.test_slice_subquery_and_query',
-                # `SHOW TABLES` doesn't distinguish between tables and views.
-                # Both are included regardless of whether inspectdb's
-                # --include-views option is set.
-                'inspectdb.tests.InspectDBTransactionalTests.test_include_views',
-                'introspection.tests.IntrospectionTests.test_table_names_with_views',
             )
         for test_name in expected_failures:
             test_case_name, _, method_name = test_name.rpartition('.')
@@ -278,35 +293,6 @@ class DatabaseCreation(PostgresDatabaseCreation):
                 klass = getattr(test_module, test_class_name)
                 setattr(test_module, test_class_name, skip('unsupported by cockroachdb')(klass))
 
-        skip_tests = (
-            # CockroachDB has more restrictive blocking than other databases.
-            # https://github.com/cockroachdb/django-cockroachdb/issues/153#issuecomment-664697963
-            'select_for_update.tests.SelectForUpdateTests.test_block',
-            # Since QuerySet.select_for_update() was enabled, this test is
-            # already skipped by the 'Database took too long to lock the row'
-            # logic in the test. Skipping it entirely prevents some error
-            # output in the logs:
-            # Exception in thread Thread-1:
-            # ...
-            # psycopg2.errors.SerializationFailure: restart transaction:
-            # TransactionRetryWithProtoRefreshError: WriteTooOldError: write
-            # at timestamp 1598314405.858850941,0 too old; wrote at
-            # 1598314405.883337663,1
-            'get_or_create.tests.UpdateOrCreateTransactionTests.test_creation_in_transaction',
-            # Sometimes fails as above or with
-            # AssertionError: datetime.timedelta(microseconds=28529) not
-            # greater than datetime.timedelta(microseconds=500000)
-            'get_or_create.tests.UpdateOrCreateTransactionTests.test_updates_in_transaction',
-        )
-        for test_name in skip_tests:
-            test_case_name, _, method_name = test_name.rpartition('.')
-            test_app = test_name.split('.')[0]
-            # Importing a test app that isn't installed raises RuntimeError.
-            if test_app in settings.INSTALLED_APPS:
-                test_case = import_string(test_case_name)
-                method = getattr(test_case, method_name)
-                setattr(test_case, method_name, skip('unsupported by cockroachdb')(method))
-
     def create_test_db(self, *args, **kwargs):
         # This environment variable is set by teamcity-build/runtests.py or
         # by a developer running the tests locally.
