@@ -7,17 +7,17 @@ from django.utils.functional import cached_property
 
 
 class DatabaseFeatures(PostgresDatabaseFeatures):
-    has_select_for_update = property(operator.attrgetter('is_cockroachdb_20_1'))
-    has_select_for_update_of = property(operator.attrgetter('is_cockroachdb_20_1'))
-    # Not supported: https://github.com/cockroachdb/cockroach/issues/40476
-    has_select_for_update_nowait = property(operator.attrgetter('is_cockroachdb_20_2'))
+    # Not supported: https://github.com/cockroachdb/cockroach/issues/6583
+    has_select_for_update = False
+    has_select_for_update_nowait = False
+    has_select_for_update_of = False
     has_select_for_update_skip_locked = False
 
     # Not supported: https://github.com/cockroachdb/cockroach/issues/31632
     can_defer_constraint_checks = False
 
     # Not supported: https://github.com/cockroachdb/cockroach/issues/9683
-    supports_partial_indexes = property(operator.attrgetter('is_cockroachdb_20_2'))
+    supports_partial_indexes = False
 
     uses_savepoints = property(operator.attrgetter('is_cockroachdb_20_1'))
     can_release_savepoints = property(operator.attrgetter('is_cockroachdb_20_1'))
@@ -39,6 +39,7 @@ class DatabaseFeatures(PostgresDatabaseFeatures):
     can_rollback_ddl = False
 
     # Not supported: https://github.com/cockroachdb/cockroach/issues/17511
+    supports_callproc_kwargs = False
     create_test_procedure_without_params_sql = None
     create_test_procedure_with_int_param_sql = None
 
@@ -56,31 +57,21 @@ class DatabaseFeatures(PostgresDatabaseFeatures):
     # Not supported: https://github.com/cockroachdb/cockroach/issues/41645
     supports_regex_backreferencing = False
 
-    # CockroachDB sorts NULL values first with ASC and last with DESC.
-    # PostgreSQL behaves the opposite.
-    nulls_order_largest = False
-
     # Introspection may work but 'CREATE MATERIALIZED VIEW' (required for the
     # test) isn't implemented: https://github.com/cockroachdb/cockroach/issues/41649
-    can_introspect_materialized_views = property(operator.attrgetter('is_cockroachdb_20_2'))
+    can_introspect_materialized_views = False
 
     introspected_big_auto_field_type = 'BigIntegerField'
+    introspected_small_auto_field_type = 'BigIntegerField'
 
     # Column ordering is supported but older versions of CockroachDB don't
     # report column ordering: https://github.com/cockroachdb/cockroach/issues/42175
     supports_index_column_ordering = property(operator.attrgetter('is_cockroachdb_20_1'))
 
-    # CockroachDB stopped creating indexes on foreign keys in 20.2.
-    indexes_foreign_keys = property(operator.attrgetter('is_not_cockroachdb_20_2'))
+    # adding a REFERENCES constraint while also adding a column via ALTER not
+    # supported: https://github.com/cockroachdb/cockroach/issues/32917
+    can_create_inline_fk = False
 
     @cached_property
     def is_cockroachdb_20_1(self):
         return self.connection.cockroachdb_version >= (20, 1)
-
-    @cached_property
-    def is_cockroachdb_20_2(self):
-        return self.connection.cockroachdb_version >= (20, 2)
-
-    @cached_property
-    def is_not_cockroachdb_20_2(self):
-        return self.connection.cockroachdb_version < (20, 2)
