@@ -2,20 +2,15 @@ from django.db.backends.base.schema import BaseDatabaseSchemaEditor
 from django.db.backends.postgresql.schema import (
     DatabaseSchemaEditor as PostgresDatabaseSchemaEditor,
 )
+from django.db.backends.utils import strip_quotes
 from django.db.models import ForeignKey
 
 
 class DatabaseSchemaEditor(PostgresDatabaseSchemaEditor):
-    # Don't include the USING clause as per
-    # https://github.com/cockroachdb/cockroach/issues/49329#issuecomment-666585887
-    sql_alter_column_type = "ALTER COLUMN %(column)s TYPE %(type)s"
-
-    @property
-    def sql_create_index(self):
-        if self.connection.features.is_cockroachdb_20_2:
-            return PostgresDatabaseSchemaEditor.sql_create_index
-        else:
-            return 'CREATE INDEX %(name)s ON %(table)s%(using)s (%(columns)s)%(extra)s'
+    # Partial indexes ('%(condition)s' in SQL string) aren't implemented in
+    # cockroachdb: https://github.com/cockroachdb/cockroach/issues/9683
+    # If implemented, this attribute can be removed.
+    sql_create_index = 'CREATE INDEX %(name)s ON %(table)s%(using)s (%(columns)s)%(extra)s'
 
     # The PostgreSQL backend uses "SET CONSTRAINTS ... IMMEDIATE" before
     # "ALTER TABLE..." to run any any deferred checks to allow dropping the
@@ -26,6 +21,10 @@ class DatabaseSchemaEditor(PostgresDatabaseSchemaEditor):
     # constraints; must use this instead.
     sql_delete_unique = "DROP INDEX %(name)s CASCADE"
 
+    # adding a REFERENCES constraint while also adding a column via ALTER not
+    # supported: https://github.com/cockroachdb/cockroach/issues/32917
+    sql_create_column_inline_fk = None
+
     def _index_columns(self, table, columns, col_suffixes, opclasses):
         # cockroachdb doesn't support PostgreSQL opclasses.
         return BaseDatabaseSchemaEditor._index_columns(self, table, columns, col_suffixes, opclasses)
@@ -42,35 +41,22 @@ class DatabaseSchemaEditor(PostgresDatabaseSchemaEditor):
             self, model, old_field, new_field, old_type, new_type, old_db_params,
             new_db_params, strict,
         )
-        # Add or remove `DEFAULT unique_rowid()` for AutoField.
-        old_suffix = old_field.db_type_suffix(self.connection)
-        new_suffix = new_field.db_type_suffix(self.connection)
-        if old_suffix != new_suffix:
-            if new_suffix:
-                self.execute(self.sql_alter_column % {
-                    'table': self.quote_name(model._meta.db_table),
-                    'changes': 'ALTER COLUMN %(column)s SET %(expression)s' % {
-                        'column': self.quote_name(new_field.column),
-                        'expression': new_suffix,
-                    }
-                })
-            else:
-                self.execute(self.sql_alter_column % {
-                    'table': self.quote_name(model._meta.db_table),
-                    'changes': 'ALTER COLUMN %(column)s DROP DEFAULT' % {
-                        'column': self.quote_name(new_field.column),
-                    }
-                })
 
     def _alter_column_type_sql(self, model, old_field, new_field, new_type):
-        if new_type.lower() in ("serial", "bigserial"):
-            column = new_field.column
-            col_type = "integer" if new_type.lower() == "serial" else "bigint"
+        self.sql_alter_column_type = 'ALTER COLUMN %(column)s TYPE %(type)s'
+        # Cast when data type changed.
+        if self._field_data_type(old_field) != self._field_data_type(new_field):
+            self.sql_alter_column_type += ' USING %(column)s::%(type)s'
+        # Make ALTER TYPE with SERIAL make sense.
+        # table = strip_quotes(model._meta.db_table)
+        serial_fields_map = {'bigserial': 'bigint', 'serial': 'integer', 'smallserial': 'smallint'}
+        if new_type.lower() in serial_fields_map:
+            column = strip_quotes(new_field.column)
             return (
                 (
                     self.sql_alter_column_type % {
                         "column": self.quote_name(column),
-                        "type": col_type,
+                        "type": serial_fields_map[new_type.lower()],
                     },
                     [],
                 ),
